import React from 'react';
import { IMenuItem } from '../Menu';
export declare type CardHeaderHeightType = 'small' | 'normal' | 'large';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
/**
 * Empty header with just a bottom border
 */
export declare const EmptyHeader: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
interface ITitleHeaderProps {
    readonly height: CardHeaderHeightType;
    readonly hasIcon: boolean;
}
interface ITabsHeaderContainerProps extends Pick<ITitleHeaderProps, 'height'> {
}
export declare const TabsHeaderContainer: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, ITabsHeaderContainerProps, never>;
export interface ICardHeaderProps extends BaseProps {
    /**
     * Label that shows inside Card Header
     */
    readonly header: string;
    /**
     * Small label that shows inside Card Header under header label
     */
    readonly subhead?: string;
    /**
     * Header height
     *
     * Default: `normal`
     */
    readonly height?: CardHeaderHeightType;
    /**
     * Optional icon
     */
    readonly icon?: React.ReactNode;
    /**
     * Menu items that shows inside menu
     */
    readonly menu?: ReadonlyArray<IMenuItem>;
    /**
     * if `true` return a header for inside tabs.
     *
     * Default: `false`
     */
    readonly tab?: boolean;
}
export declare const CardHeader: React.FC<ICardHeaderProps>;
export interface ICardExpandableHeaderProps extends ICardHeaderProps {
    readonly disabled?: boolean;
    readonly expanded?: boolean;
    readonly onToggle: (expanded: boolean) => void;
}
export declare const CardExpandableHeader: React.FC<ICardExpandableHeaderProps>;
export {};
