import React from 'react';
import { RadioButtonChangeHandler, RadioButtonValueChangeHandler } from '../RadioButton';
import { IconType } from '../Icon';
import { IFieldProps } from '../utils';
declare type BaseElement = HTMLInputElement;
declare type BaseProps = React.InputHTMLAttributes<BaseElement>;
export interface IRadioIconButtonProps<V extends string = string> extends BaseProps {
    /**
     * Attributes a name to the RadioIconButton.
     */
    readonly name: string;
    /**
     * Value used to define the button text.
     */
    readonly value: V;
    /**
     * String used to label the RadioIconButton.
     */
    readonly label: string;
    /**
     * If `true`, the component is checked.
     */
    readonly checked: boolean;
    /**
     * If `true`, the RadioIconButton will be disabled.
     */
    readonly disabled?: boolean;
    /**
     * Adds an error message to the RadioIconButton.
     */
    readonly error?: string;
    /**
     * The icon element.
     */
    readonly icon: IconType;
    /**
     * Native change handler that can be used by formik etc.
     */
    readonly onChange?: RadioButtonChangeHandler;
    /**
     * Smooth typed value change handler.
     */
    readonly onValueChange?: RadioButtonValueChangeHandler<V>;
}
export declare function RadioIconButton<V extends string = string>({ label, checked, disabled, onChange, onValueChange, icon, onFocus, onPointerUp, onPointerDown, ...rest }: IRadioIconButtonProps<V>): JSX.Element;
export interface IRadioIconGroupOption<V extends string = string> {
    readonly value: V;
    readonly label: string;
    readonly disabled?: boolean;
    readonly icon: IconType;
}
declare type GroupBaseElement = HTMLDivElement;
declare type GroupBaseProps = React.HTMLAttributes<GroupBaseElement>;
export interface IRadioIconGroupProps<V extends string = string> extends GroupBaseProps {
    readonly options: ReadonlyArray<IRadioIconGroupOption<V>>;
    readonly name?: string;
    readonly value: V;
    readonly onChange?: RadioButtonChangeHandler;
    readonly onValueChange?: RadioButtonValueChangeHandler<V>;
    readonly error?: string;
}
export declare function RadioIconGroup<V extends string = string>({ options, name, value, onChange, onValueChange, error, ...rest }: IRadioIconGroupProps<V>): JSX.Element;
export declare const RadioIconGroupField: <V extends string = string>(props: IFieldProps & IRadioIconGroupProps<V>) => React.ReactElement<any, any> | null;
export {};
